@@ -153,7 +153,7 @@ def quantify_df(df, target_units, errors):
             try:
                 df_num[(col, col_units)] = pd.to_numeric(df[(col, col_units)])
             except ValueError as exc:
-                errors[(col, "?")] = "cannot convert some values to numeric"
+                errors[(col, "?")].append("cannot convert some values to numeric")
                 df_nonnum[(col, col_units)] = df[(col, col_units)]
                 continue
         else:
